@@ -3,7 +3,7 @@ BEGIN {
   $BenchmarkAnything::Storage::Frontend::HTTP::Controller::Search::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: BenchmarkAnything - REST API - data query
-$BenchmarkAnything::Storage::Frontend::HTTP::Controller::Search::VERSION = '0.006';
+$BenchmarkAnything::Storage::Frontend::HTTP::Controller::Search::VERSION = '0.007';
 use Mojo::Base 'Mojolicious::Controller';
 
 
@@ -23,11 +23,11 @@ sub search
         my $query    = $self->req->json;
 
         if ($value_id) {
-                $self->render(json => $self->backend->get_single_benchmark_point($value_id));
+                $self->render(json => $self->app->backend->get_single_benchmark_point($value_id));
         }
         elsif ($query)
         {
-                $self->render(json => $self->backend->search_array($query));
+                $self->render(json => $self->app->backend->search_array($query));
         }
         else
         {
@@ -43,9 +43,9 @@ sub listnames
         my $pattern = $self->param('pattern');
 
         my @pattern = $pattern ? ($pattern) : ();
-        my $answer = $self->backend->list_benchmark_names(@pattern);
+        my $answer = $self->app->backend->list_benchmark_names(@pattern);
 
-        $self->render(json => $self->backend->list_benchmark_names(@pattern));
+        $self->render(json => $self->app->backend->list_benchmark_names(@pattern));
 }
 
 1;
