@@ -3,7 +3,7 @@ BEGIN {
   $BenchmarkAnything::Storage::Frontend::HTTP::Controller::Submit::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: BenchmarkAnything - REST API - data submit
-$BenchmarkAnything::Storage::Frontend::HTTP::Controller::Submit::VERSION = '0.006';
+$BenchmarkAnything::Storage::Frontend::HTTP::Controller::Submit::VERSION = '0.007';
 use Mojo::Base 'Mojolicious::Controller';
 
 
@@ -16,12 +16,12 @@ sub add
         if ($data)
         {
                 if (!$ENV{HARNESS_ACTIVE}) {
-                        my $orig = $self->balib->{queuemode};
-                        $self->balib->{queuemode} = 1;
-                        $self->balib->add($data);
-                        $self->balib->{queuemode} = $orig;
+                        my $orig = $self->app->balib->{queuemode};
+                        $self->app->balib->{queuemode} = 1;
+                        $self->app->balib->add($data);
+                        $self->app->balib->{queuemode} = $orig;
                 } else {
-                        $self->balib->add($data);
+                        $self->app->balib->add($data);
                 }
         }
         # how to report error?
